@@ -2,5 +2,5 @@
 # cette fonction permet de vérifier si une année est bissextile ou pas
 
 
-def anneebissextile (annee):
+def annee_bissextile (annee):
     return annee % 4 == 0 and (annee % 100 != 0 or annee % 400 == 0)
\ No newline at end of file
